homology.dim0.unionfind — GDA Toolbox v1.0 Manual

# homology.dim0.unionfind

`homology.dim0.` `unionfind`()

  Apply the UnionFind algorithm to compute zero-dimensional persistence diagram. Connected components are born at the height of a vertex. Connected components merge/die at the height of the joining edge.

  Parameters: | myobject : `multidim.SimplicialComplex`, `multidim.PointCloud`, or `timeseries.Signal` The algorithm requires heights on the vertices and heights on the edges. cutoff : `numpy.float64` Stop computing persistence at height `cutoff`.
  Returns: | birth_index : `numpy.ndarray` death_index : `numpy.ndarray` birth_height : `numpy.ndarray` death_height : `numpy.ndarray` mergetree : stdtypes.dict The mergetree is a dictionary keyed by the index of vertices where a merge occurred. The values of the dictionary are the previous representatives that were merged.

  Notes

  If the input object has \(n\) edges, then this functiomn calls `homology.dim0.merge()` a total of \(n\) times, and it calls `persistence.fast_algorithms.root()` a total of \(2n\) times.

  References

  [1] | H. Edelsbrunner and J. Harer, Computational Topology: An Introduction. American Mathematical Soc., 2010.

#### Previous topic

homology.dim0.mkforestDBL

#### Next topic

homology.dim1